'use strict';
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
var installer_1 = require("./dynamodb/installer");
var starter_1 = require("./dynamodb/starter");
var utils_1 = require("./dynamodb/utils");
var config_json_1 = __importDefault(require("./dynamodb/config.json"));
var DynamodbLocalManager = /** @class */ (function () {
    function DynamodbLocalManager() {
        this.dbInstances = {};
    }
    DynamodbLocalManager.prototype.install = function (callback, path) {
        if (path) {
            config_json_1.default.setup.install_path = path;
        }
        var installer = new installer_1.Installer();
        installer.install(config_json_1.default, function (msg) {
            console.log(msg);
            callback();
        });
    };
    DynamodbLocalManager.prototype.start = function (options) {
        var starter = new starter_1.Starter();
        var instance = starter.start(options, config_json_1.default);
        this.dbInstances[instance.port] = {
            process: instance.proc,
            options: options
        };
        instance.proc.on('close', function (code) {
            if (code !== null && code !== 0) {
                console.log('DynamoDB Local failed to start with code', code);
            }
        });
        console.log('Dynamodb Local Started, Visit: http://localhost:' + (options.port || config_json_1.default.start.port) + '/shell');
    };
    DynamodbLocalManager.prototype.stop = function (port) {
        if (this.dbInstances[port]) {
            this.dbInstances[port].process.kill('SIGKILL');
            delete this.dbInstances[port];
        }
    };
    DynamodbLocalManager.prototype.restart = function (port) {
        var options = this.dbInstances[port].options;
        this.stop(port);
        this.start(options);
        console.log('Successfully restarted dynamodb local on port: ' + port);
    };
    DynamodbLocalManager.prototype.remove = function (callback) {
        var utils = new utils_1.Utils();
        utils.removeDir(config_json_1.default.setup.install_path);
    };
    return DynamodbLocalManager;
}());
exports.DynamodbLocalManager = DynamodbLocalManager;
//# sourceMappingURL=index.js.map